@@ -5,7 +5,7 @@ use warnings;
 use 5.010;
 use parent qw/autobox/;
 
-our $VERSION = "1.026";
+our $VERSION = "1.027";
 
 =head1 NAME
 
@@ -41,6 +41,7 @@ particular when the values are hashrefs or objects.
     $book_types->filter("scifi");
     $book_types->filter({ fantasy => 1, scifi => 1 }); # hash key exists
 
+    # order (like a more succinct sort)
     $book_types->order;
     $book_types->order("desc");
     $book_prices->order([ "num", "desc" ]);
@@ -90,7 +91,10 @@ particular when the values are hashrefs or objects.
     $books->order_by(price => [ "num", "desc" ]);
     $books->order_by(name => [ sub { uc($_) }, "desc" ]);
     $books->order_by([ price_with_tax => $rate ] => "num");
-    $books->order_by(author => "str", price => [ "num", "desc" ]);
+    $books->order_by(
+        author => "str",             # first by author
+        price  => [ "num", "desc" ], # then by price, most expensive first
+    );
     $books->order_by(
         author                      => [ "desc", sub { uc($_) } ],
         [ price_with_tax => $rate ] => [ "num", "desc" ],
@@ -186,6 +190,10 @@ $array->filter()
 
 =item
 
+$array->order()
+
+=item
+
 $array->flat()
 
 =item
@@ -210,6 +218,10 @@ $array->uniq_by()
 
 =item
 
+$array->order_by()
+
+=item
+
 $array->group_by()
 
 =item
@@ -348,19 +360,19 @@ sub _predicate {
 
 =head2 Transforming lists of objects vs list of hashrefs
 
-C<map_by>, C<filter_by> etc. (all methods named C<*_by>) work with
-sets of hashrefs or objects.
+C<map_by>, C<filter_by> C<order_by> etc. (all methods named C<*_by>)
+work with sets of hashrefs or objects.
 
 These methods are called the same way regardless of whether the array
 contains objects or hashrefs. The items in the list must be either all
 objects or all hashrefs.
 
-If the array contains objects, a method is called on each object
-(possibly with the arguments provided).
-
 If the array contains hashrefs, the hash key is looked up on each
 item.
 
+If the array contains objects, a method is called on each object
+(possibly with the arguments provided).
+
 =head3 Calling accessor methods with arguments
 
 For method calls, it's possible to provide arguments to the method.
@@ -416,10 +428,10 @@ whatever you use to avoid upgrading modules to incompatible versions.
 
 =head2 Filter predicates
 
-There are several methods that filter items, e.g. C<@array->filter>
-(duh), C<@array->filter_by>, and C<%hash->filter_each>. These methods
-take a $predicate argument to determine which items to retain or
-filter out.
+There are several methods that filter items,
+e.g. C<@array-E<gt>>filter> (duh), C<@array-E<gt>>filter_by>, and
+C<%hash-E<gt>>filter_each>. These methods take a $predicate argument to
+determine which items to retain or filter out.
 
 If $predicate is an I<unblessed scalar>, it is compared to each value
 with C<string eq>.
@@ -458,17 +470,21 @@ autobox::Core.
 
 Beware: you might be in list context when you need an arrayref.
 
-When in doubt, assume they work like C<map> and C<grep>, and convert
-the return value to references where you might have an unobvious list
-context. E.g.
+When in doubt, assume they work like C<map> and C<grep> (i.e. return a
+list), and convert the return value to references where you might have
+an unobvious list context. E.g.
+
+=head3 Incorrect
 
     $self->my_method(
-        # Wrong, this is list context and wouldn't return an arrayref
+        # Wrong, this is list context and wouldn't return an array ref
         books => $books->filter_by("is_published"),
     );
 
+=head3 Correct
+
     $self->my_method(
-        # Correct, convert the returned list to an arrayref
+        # Correct, put the returned list in an anonymous array ref
         books => [ $books->filter_by("is_published") ],
     );
     $self->my_method(
@@ -476,9 +492,9 @@ context. E.g.
         books => scalar $books->filter_by("is_published"),
     );
 
-    # Probably the nicest, since it goes at the end
+    # Probably the nicest, since ->to_ref goes at the end
     $self->my_method(
-        # Correct, use ->to_ref to ensure an array reference is returned
+        # Correct, use ->to_ref to ensure an array ref is returned
         books => $books->filter_by("is_published")->to_ref,
     );
 
@@ -493,17 +509,21 @@ autobox::Transform's C<order>/C<order_by>.
 
 =over 4
 
-=item provide a sub that returns the comparison outcome of two values: $a and $b
+=item *
 
-=item in case of a tie, provide another comparison of $a and $b
+provide a sub that returns the comparison outcome of two values: $a and $b
+
+=item *
+
+in case of a tie, provide another comparison of $a and $b
 
 =back
 
     # If the name is the same, compare age (oldest first)
     sort {
-        uc( $a->{name} ) cmp uc( $b->{name} )
+        uc( $a->{name} ) cmp uc( $b->{name} )           # first comparison
         ||
-        int( $b->{age} / 10 ) <=> int( $a->{age} / 10 )
+        int( $b->{age} / 10 ) <=> int( $a->{age} / 10 ) # second comparison
     } @users
 
 (note the opposite order of $a and $b for the age comparison,
@@ -513,19 +533,29 @@ something that's often difficult to discern at a glance)
 
 =over 4
 
-=item provide order options for how one value should be compared with the others
+=item *
+
+Provide order options for how one value should be compared with the others:
 
 =over 8
 
-=item how to compare (cmp or <=>)
+=item *
 
-=item which direction to sort (ascending or descending)
+how to compare (cmp or <=>)
 
-=item the value can be transformed using an optional subref, e.g. by uc($_)
+=item *
+
+which direction to sort (ascending or descending)
+
+=item *
+
+which value to compare, using a subref, e.g. by uc($_)
 
 =back
 
-=item in case of a tie, provide another comparison
+=item *
+
+In case of a tie, provide another comparison
 
 =back
 
@@ -554,9 +584,13 @@ There are comparison options for how to compare values
 
 =over 4
 
-=item C<str> (cmp) - default
+=item *
 
-=item C<num> (<=>)
+C<str> (cmp) - default
+
+=item *
+
+C<num> (<=>)
 
 =back
 
@@ -565,9 +599,13 @@ There are comparison options for how to compare values
 
 =over 4
 
-=item C<asc> (ascending) - default
+=item *
 
-=item C<desc> (descending)
+C<asc> (ascending) - default
+
+=item *
+
+C<desc> (descending)
 
 =back
 
@@ -576,19 +614,27 @@ There are comparison options for how to compare values
 
 =over 4
 
-=item A subref - default is: sub { $_ }
+=item *
+
+A subref - default is: sub { $_ }
 
 =over 8
 
-=item The return value is used in the comparison
+=item *
+
+The return value is used in the comparison
 
 =back
 
-=item A regex
+=item *
+
+A regex
 
 =over 8
 
-=item The value of join("", @captured_groups) are used in the comparison (@captured_groups are $1, $2, $3 etc.)
+=item *
+
+The value of join("", @captured_groups) are used in the comparison (@captured_groups are $1, $2, $3 etc.)
 
 =back
 
@@ -599,16 +645,18 @@ There are comparison options for how to compare values
     ## A single comparison
 
     # order: the first arg is the comparison options (one or an
-    # arrayref with many)
+    # arrayref with many options)
     ->order()  # Defaults to str, asc, $_, just like sort
     ->order("num")
     ->order(sub { uc($_) })
+    # compare captured matches, e.g. "John" and "Doe" as "JohnDoe"
     ->order( qr/first_name: (\w+), last_name: (\w+)/ )
     ->order([ num => qr/id: (\d+)/ ])
     ->order([ sub { int($_) }, "num" ])
 
-    # order_by: the first arg is the accessor, second arg is the
-    # comparison options (one or an arrayref with many)
+    # order_by: the first arg is the accessor, just like with
+    # map_by. Second arg is the comparison options (one or an arrayref
+    # with many options)
     ->order_by("id")
     ->order_by("id", "num")
     ->order_by("id", [ "num", "desc" ])
@@ -616,21 +664,24 @@ There are comparison options for how to compare values
     ->order_by(log_line => qr/first_name: (\w+), last_name: (\w+)/ )
     ->order_by("log_line", [ num => qr/id: (\d+)/ ])
     ->order_by(age => [ sub { int($_) }, "num" ])
-    ->order_by([ age_by_interval => 10 ] => [ sub { int($_) }, "num" ])
+
+    # compare int( $a->age_by_interval(10) )
+    ->order_by([ age_by_interval => 10 ] => [ sub { int($_) }, "num" ]) 
+    # compare uc( $a->name_with_title($title) )
     ->order_by([ name_with_title => $title ], sub { uc($_) })
 
 
     ## Multiple comparisons
     # order: subsequent comparison options are added as needed (one or
     # an arrayref with many, per comparison)
-    ->order(
-        [ sub { uc($_) }, "desc" ],
-        "str",
-    )
     ->order(
         [ sub { $_->{price} }, "num" ], # First a numeric comparison of price
         [ sub { $_->{name} }, "desc" ], # or if same, a reverse comparison of the name
     )
+    ->order(
+        [ sub { uc($_) }, "desc" ],
+        "str",
+    )
     ->order(
         qr/type: (\w+)/,
         [ num => desc => qr/duration: (\d+)/ ]
@@ -638,7 +689,7 @@ There are comparison options for how to compare values
         "str",
     )
 
-    # order_by:
+    # order_by: pairs of accessor-comparison options
     ->order(
         price => "num", # First a numeric comparison of price
         name => "desc", # or if same, a reverse comparison of the name
@@ -647,6 +698,7 @@ There are comparison options for how to compare values
         price => [ "num", "desc" ],
         name  => "str",
     )
+    # accessor is a method call with arg: $_->price_with_discount($discount)
     ->order(
         [ price_with_discount => $discount ] => [ "num", "desc" ],
         name                                 => [ str => sub { uc($_) } ],
@@ -654,11 +706,6 @@ There are comparison options for how to compare values
     )
 
 
-=head3 Order methods
-
-See L</order> and L</order_by>
-
-
 
 =head1 METHODS ON ARRAYS
 
@@ -892,72 +939,6 @@ sub order {
     return wantarray ? @$result : $result;
 }
 
-=head2 @array->order_by(@accessor_comparison_pairs) : @array | @$array
-
-Return @array ordered according to the @accessor_comparison_pairs.
-
-The comparison value comes from an initial map_by($accessor) on each
-@array item. It then works just like with C<-E<gt>>order_by>.
-
-    $books->order_by(price => "num");
-    $books->order_by(price => [ "num", "desc" ]);
-
-It is important that the C<map_by> call returns exactly a single
-scalar that can be compared with the other values.
-
-Just like with C<order>, the value to actually compare can be
-transformed using a sub, or be matched against a regex.
-
-    $books->order_by(price => [ num => sub { int($_) } ]);
-
-    # Ignore leading "The" in book titles by optionally matching it
-    # with a non-capturing group and the rest with a capturing paren
-    $books->order_by( title => qr/^ (?: The \s+ )? (.+) /x );
-
-If a comparison is missing for the last pair, the default is a normal
-C<str> comparison.
-
-    $books->order_by("name"); # default "str"
-
-If the first comparison ends in a tie, the next pair is used,
-etc. Note that in order to provide accessor-comparison pairs, it's
-often necessary to provide a default "str" comparison just to make it
-a pair.
-
-    $books->order_by(
-        author => "str",
-        price  => [ "num", "desc" ],
-    );
-
-=cut
-
-sub order_by {
-    my $array = shift;
-    my (@accessors_and_comparisons) = @_;
-
-    my $i = 0;
-    my ($accessors, $comparisons) = List::MoreUtils::part
-        { $i++ %2 }
-        @accessors_and_comparisons;
-    $accessors   ||= [];
-    $comparisons ||= [];
-    @$accessors or Carp::croak("->order_by() missing argument: \$accessor");
-    # Default comparison
-    @$accessors == @$comparisons or push(@$comparisons, "str");
-
-    my ($sorter, $extracts) = _sorter_from_comparisons("order_by", $comparisons);
-
-    my $item_values_array = _item_values_array_from_map_by_extracts(
-        $array,
-        $accessors,
-        $extracts,
-    );
-    my $sorted_array = $sorter->($item_values_array);
-    my $result = [ map { $_->[0] } @$sorted_array ];
-
-    return wantarray ? @$result : $result;
-}
-
 
 
 =head2 @array->flat() : @array | @$array
@@ -1226,7 +1207,73 @@ sub uniq_by {
     return __invoke_by("uniq", $array, $accessor, $args);
 }
 
+=head2 @array->order_by(@accessor_comparison_pairs) : @array | @$array
 
+Return @array ordered according to the @accessor_comparison_pairs.
+
+The comparison value comes from an initial C<map_by($accessor)> on
+each @array item. It then works just like with C<-E<gt>order_by>.
+
+    $books->order_by("name");
+    $books->order_by(price => "num");
+    $books->order_by(price => [ "num", "desc" ]);
+
+It is important that the C<map_by> call returns exactly a single
+scalar that can be compared with the other values.
+
+Just like with C<order>, the value to actually compare can be
+transformed using a sub, or be matched against a regex.
+
+    $books->order_by(price => [ num => sub { int($_) } ]);
+
+    # Ignore leading "The" in book titles by optionally matching it
+    # with a non-capturing group and the rest with a capturing group
+    # paren
+    $books->order_by( title => qr/^ (?: The \s+ )? (.+) /x );
+
+If a comparison is missing for the last pair, the default is a normal
+C<str> comparison.
+
+    $books->order_by("name"); # default "str"
+
+If the first comparison ends in a tie, the next pair is used,
+etc. Note that in order to provide accessor-comparison pairs, it's
+often necessary to provide a default "str" comparison just to make it
+a pair.
+
+    $books->order_by(
+        author => "str",
+        price  => [ "num", "desc" ],
+    );
+
+=cut
+
+sub order_by {
+    my $array = shift;
+    my (@accessors_and_comparisons) = @_;
+
+    my $i = 0;
+    my ($accessors, $comparisons) = List::MoreUtils::part
+        { $i++ %2 }
+        @accessors_and_comparisons;
+    $accessors   ||= [];
+    $comparisons ||= [];
+    @$accessors or Carp::croak("->order_by() missing argument: \$accessor");
+    # Default comparison
+    @$accessors == @$comparisons or push(@$comparisons, "str");
+
+    my ($sorter, $extracts) = _sorter_from_comparisons("order_by", $comparisons);
+
+    my $item_values_array = _item_values_array_from_map_by_extracts(
+        $array,
+        $accessors,
+        $extracts,
+    );
+    my $sorted_array = $sorter->($item_values_array);
+    my $result = [ map { $_->[0] } @$sorted_array ];
+
+    return wantarray ? @$result : $result;
+}
 
 =head2 @array->group_by($accessor, $value_subref = object) : %key_value | %$key_value
 
